* patch cis and charges and subtypes 
* renumber chains
* offset shifts
* assign
* mars
* nmrview output
* nmrpipe output
* Xplor xplor
* Aria
* nmrstar -peaks sequence
* Missing tests
* Rename atoms
* Fasta export
* xEasy shifts
* Xplor shifts export?

release